/*********************************************************************
 * Job Ticket API (JTAPI)                                            
 *                                                                   
 * Copyright (c) 2003 International Business Machines Corp.          
 * Copyright (c) 2003 Free Standards Group.          
 *                                                                    
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS COMMON 
 * PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION 
 * OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * jtapi_cpl.h and applies to the contents of this file. 
 *********************************************************************/

#ifndef JTAPI_JOB_TICKET_INFO_H
#define JTAPI_JOB_TICKET_INFO_H

#include <stdio.h>
#include <jtapi.h>

/* Defined constant to use for the type of this jtapi object */
#define JTAPI_JOB_TICKET_TYPE    "JTAPI_JOB_TICKET"

/************************************************************
 * Job Ticket Info attributes
 ***********************************************************/
#define JT_API_VERSION     "jt-api-version"
#define JT_COMMENT         "jt-comment"
#define JT_LENGTH_UNIT     "jt-length-unit"
#define JT_TYPE            "jt-type-and-version"

/************************************************************
 * Other constants
 ***********************************************************/
#define JTAPI_API_VERSION        "alpha"

/************************************************************
 * newJobTicketInfoFromURI - Creates a JobTicketInfo object 
 * from the job ticket file at the provided URI. Other JTAPI 
 * objects are also created based on the information in the 
 * job ticket file.
 *
 * param jtapi_object_t* jobTicketInfo - Pointer to the new 
 *      JobTicketInfo
 * param char* uri - URI where job ticket file resides.
 *
 * return parser_status_t
 ***********************************************************/
parser_status_t newJobTicketInfoFromURL(
              jtapi_object_t* jobTicketInfo,
              char* uri);

/************************************************************
 * newJobTicketInfoFromStream - Creates a JobTicketInfo 
 * object from the provided stream that contains a job 
 * ticket. Other JTAPI objects are also created based on the 
 * information in the job ticket file.
 *
 * param jtapi_object_t* jobTicketInfo - Pointer to the new 
 *      JobTicketInfo
 * param FILE* stream - Stream that contains a job ticket
 *
 * return parser_status_t
 ***********************************************************/
parser_status_t newJobTicketInfoFromStream(
                jtapi_object_t* jobTicketInfo,
                FILE* stream);

/************************************************************
 * newJobTicketInfoFromJob - Creates a JobTicketInfo object 
 * using the provided Job object. Used when a new job ticket 
 * is being created. The Job object must be created first.
 *
 * param jtapi_object_t* jobTicketInfo - Pointer to the new 
 *      JobTicketInfo
 * param jtapi_object_t job - Job object for the 
 *      JobTicketInfo to be created
 *
 * return jtapi_status_t
 ***********************************************************/
jtapi_status_t newJobTicketInfoFromJob(
                jtapi_object_t* jobTicketInfo,
                jtapi_object_t job);

/************************************************************
 * getJob - Get the Job that this JobTicketInfo contains.
 *
 * param jtapi_object_t job - JobTicketInfo to get the job 
 *      from
 *
 * return jtapi_object_t - This JobTicketInfo's Job
 ***********************************************************/
jtapi_object_t getJob(jtapi_object_t jobTicketInfo);

/************************************************************
 * writeJobTicketStream - Writes a job ticket to the provided 
 *      stream.
 *
 * param jtapi_object_t jobTicketInfo - JobTicketInfo from 
 *      which the job ticket is to be written
 * param FILE* stream - Stream to write the job ticket to
 *
 * return jtapi_status_t
 ***********************************************************/
jtapi_status_t writeJobTicketStream(jtapi_object_t jobTicketInfo,
                                    FILE* stream);

/************************************************************
 * writeJobTicketURI - Writes a job ticket at the provided 
 *      URI.
 *
 * param jtapi_object_t jobTicketInfo - JobTicketInfo from 
 *      which the job ticket is to be written
 * param char* uri - URI of the job ticket that is to be 
 *      created from the JobTicketInfo. 
 *
 * return jtapi_status_t
 ***********************************************************/
jtapi_status_t writeJobTicketURI(jtapi_object_t jobTicketInfo,
                                 char* uri);

#endif /* JTAPI_JOB_TICKET_INFO_H */
